package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.AppVersion;

/**
 * versionService接口
 * 
 * @author ruoyi
 * @date 2023-06-13
 */
public interface IAppVersionService extends IService<AppVersion>
{
    /**
     * 查询version
     * 
     * @param id version主键
     * @return version
     */
    public AppVersion selectAppVersionById(Long id);

    /**
     * 查询version列表
     * 
     * @param appVersion version
     * @return version集合
     */
    public List<AppVersion> selectAppVersionList(AppVersion appVersion);

    /**
     * 新增version
     * 
     * @param appVersion version
     * @return 结果
     */
    public int insertAppVersion(AppVersion appVersion);

    /**
     * 修改version
     * 
     * @param appVersion version
     * @return 结果
     */
    public int updateAppVersion(AppVersion appVersion);

    /**
     * 批量删除version
     * 
     * @param ids 需要删除的version主键集合
     * @return 结果
     */
    public int deleteAppVersionByIds(Long[] ids);

    /**
     * 删除version信息
     * 
     * @param id version主键
     * @return 结果
     */
    public int deleteAppVersionById(Long id);
}
